@@ -83,6 +83,8 @@ def _is_tuple(arg):
 
 
 def _expand_tuple(arg, denominator_method):
+    if len(arg) == 0:
+        return {() : 1}
     subdatas = [_expand(x, denominator_method) for x in arg]
     data = defaultdict(int)
     for t in itertools.product(*(subdata.items() for subdata in subdatas)):
@@ -123,6 +125,8 @@ def _merge_subdatas(subdatas, weights, denominator_method):
             data[outcome] += weight * factor
 
     if denominator_method == 'reduce':
-        data = data.reduce()
+        gcd = math.gcd(*data.values())
+        if gcd > 1:
+            data = {outcome: weight // gcd for outcome, weight in data.items()}
 
     return data
